<?php
require_once( "config.class.php" );
class configure extends config {
	private $cfg_vars = array();

	function __construct() {
		parent::__construct();
		/**	Alle Variablen die fuer die Wecker-Konfiguration
			notwendig sind aus dem config-File auslesen.
		*/
		$this->cfg_vars = $this->get_cfg_vars( $this->config_dir."/config", array(
			"INITIAL_VOLUME",
			"AUTOSTART",
			"AUTOSTARTSTREAM",
			"IFUP",
			"IP",
			"SNMASK",
			"GATEWAY",
			"NAMESERVER"
		) );
	}

	private function codeToMessage( $code ) {
		switch( $code ) {
			case UPLOAD_ERR_INI_SIZE:
				$message = "Die hochgeladene Datei hat die maximale Dateigr&ouml;&szlig;e der upload_max_filesize-Direktive in der php.ini &uuml;berschritten.";
				break;
			case UPLOAD_ERR_FORM_SIZE:
				$message = "Die hochgeladene Datei hat die MAX_FILE_SIZE-Direktive des Upload-Formulars &uuml;berschritten";
				break;
			case UPLOAD_ERR_PARTIAL:
				$message = "Die Datei wurde nicht vollst&auml;ndig hochgeladen.";
				break;
			case UPLOAD_ERR_NO_FILE:
				$message = "Es wurde keine Datei hochgeladen.";
				break;
			case UPLOAD_ERR_NO_TMP_DIR:
				$message = "Es wurde kein Temp-Ordner gefunden.";
				break;
			case UPLOAD_ERR_CANT_WRITE:
				$message = "Fehler beim Schreiben der Datei auf die Festplatte.";
				break;
			case UPLOAD_ERR_EXTENSION:
				$message = "Dateiupload wegen ung&uuml;ltiger Dateierweiterung gestoppt.";
				break;
			case UPLOAD_ERR_OK:
				$message = "Datei wurde hochgeladen.";
				break;
			default:
				$message = "Unbekannter Fehler.";
				break;
			}
		return( $message );
	}

	public function get_startoptions() {
		return( array(
			"AUTOSTART" => ( ( $this->cfg_vars['AUTOSTART'] == "yes" ) ? true : false ),
			"VOLUME" => $this->cfg_vars['INITIAL_VOLUME'],
			"STREAM" => $this->cfg_vars['AUTOSTARTSTREAM']
		) );

	}

	public function set_startoptions( $values ) {
		$regex = array(
			"/INITIAL_VOLUME=.*/i",
			"/AUTOSTART=.*/i",
			"/AUTOSTARTSTREAM=.*/i"
		);

		$value = array(
			"INITIAL_VOLUME=".$values['cfg_volume'],
			"AUTOSTART=".( ( $values['cfg_autostart'] == "yes" ) ? "yes" : "no" ),
			"AUTOSTARTSTREAM=".$values['cfg_stream']
		);

		$this->cfg_vars[ "INITIAL_VOLUME" ] = $values['cfg_volume'];
		$this->cfg_vars[ "AUTOSTART" ] = ( $values['cfg_autostart'] == "yes" ) ? "yes" : "no";
		$this->cfg_vars[ "AUTOSTARTSTREAM" ] = $values['cfg_stream'];

		return( $this->replace_file_regex( $this->config_dir."/config", $regex, $value ) );
	}

	public function get_ipoptions() {
		if( $this->cfg_vars['IFUP'] == "dhcp" ) {
			$_return = array(
				"IFUP" => "dhcp",
				"IP" => array( "", "", "", "" ),
				"SNMASK" => array( "", "", "", "" ),
				"GATEWAY" => array( "", "", "", "" ),
				"NAMESERVER" => array( "", "", "", "" )
			);
		} else {
			$_return = array(
				"IFUP" => "static",
				"IP" => explode( ".", $this->cfg_vars['IP'] ),
				"SNMASK" => explode( ".", $this->cfg_vars['SNMASK'] ),
				"GATEWAY" => explode( ".", $this->cfg_vars['GATEWAY'] ),
				"NAMESERVER" => explode( ".", $this->cfg_vars['NAMESERVER'] )
			);
		}
		return( $_return );
	}

	public function set_ipoptions( $values ) {
		if( $values['cfg_ifcfg'] == "dhcp" ) {
			$this->cfg_vars['IFUP'] = "dhcp";
			$this->cfg_vars['IP'] = "";
			$this->cfg_vars['SNMASK'] = "";
			$this->cfg_vars['GATEWAY'] = "";
			$this->cfg_vars['NAMESERVR'] = "";
			return( $this->replace_file_regex( $this->config_dir."/config", "/IFUP=.*/i", "IFUP=dhcp" ) );
		} else {
			$regex = array(
				"/IFUP=.*/i",
				"/IP=.*/I",
				"/SNMASK=.*/i",
				"/GATEWAY=.*/i",
				"/NAMESERVER=.*/i"
			);

			$value = array(
				"IFUP=static",
				"IP=".$values['cfg_ip'],
				"SNMASK=".$values['cfg_sn'],
				"GATEWAY=".$values['cfg_gw'],
				"NAMESERVER=".$values['cfg_ns']
			);

			$this->cfg_vars['IFUP'] = "static";
			$this->cfg_vars['IP'] = $values['cfg_ip'];
			$this->cfg_vars['SNMASK'] = $values['cfg_sn'];
			$this->cfg_vars['GATEWAY'] = $values['cfg_gw'];
			$this->cfg_vars['NAMESERVR'] = $values['cfg_ns'];

			return( $this->replace_file_regex( $this->config_dir."/config", $regex, $value ) );
		}
	}

	public function vobdel( $vob ) {
		if( file_exists( $this->vobdir."/$vob" ) && is_file( $this->vobdir."/$vob" ) ) {
			if( substr( $vob, 0, 1 ) == "." OR substr( $vob, 0, 1 ) == "/" ) {
				$this->addError( "Der angegebene Dateiname ist ung&uuml;ltig!" );
				return( false );
			} else {
				unlink( $this->vobdir."/$vob" );
				// voblist neu einlesen
				$this->get_voblist( true );
				return( true );
			}
		} else {
			$this->addError( "Die angegebene Datei existiert nicht!" );
			return( false );
		}
	}

	public function upload_vob() {
		if( $_FILES['cfg_upload']['size'] > 10 AND $_FILES['cfg_upload']['size'] < 100*1024 ) {
			$sizeOK = true;
		}
		$file_mimes = array( "audio/mpeg", "audio/x-mpeg", "audio/mp3", "audio/x-mp3", "audio/mpeg3", "audio/x-mpeg3", "audio/mpg", "audio/x-mpg", "audio/x-mpegaudio" );
		if( in_array( $_FILES['cfg_upload']['type'], $mime_type ) ) {
			$typeOK = true;
		}
		if( $_FILES['file']['error'] === UPLOAD_ERR_OK AND is_uploaded_file( $_FILES['cfg_upload']['tmp_name'] ) AND $sizeOK AND $typeOK ) {

			// Dateien mit gleichem Namen nicht ueberschrieben!
			$prename = 0;
			while( file_exists( $this->vobdir."/".$_FILES['cfg_upload']['name'] ) ) {
				$prename++;
			}
			if( $prename == 0 ) $prename = "";
			else $prename .= "_";

			move_uploaded_file( $_FILES['cfg_upload']['tmp_name'], $this->vob_dir."/".$prename.$_FILES['cfg_upload']['name'] );
/**
	@TODO: auskommentieren, sobald mpd-Klasse fertig ist!
			require_once( "mpd.class.php" );
			$mpd = new mpd;
			$mpd->reload_files();*/

			return( true );
		} else {
			if( !$sizeOk ) $this->addError( "Die hochgeladene Datei ist zu gro&szlig;!" );
			if( !$typeOK ) $this->addError( "Die hochgeladene Datei ist keine MP3-Datei!" );
			$this->addError( $this->codeToMessage( $_FILES['cfg_upload']['error'] ) );
			return( false );
		}
	}
}
?>
